@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.20 2004/03/26 22:10:03 adamh Exp $
+ *  $Id: ephy-embed-single.c,v 1.24 2004/07/22 18:15:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -81,6 +81,23 @@ ephy_embed_single_iface_init (gpointer g_class)
 		      G_TYPE_STRING,
 		      G_TYPE_STRING);
 
+/**
+ * EphyEmbedSingle::network-status:
+ * @single:
+ * @offline: the network status
+ *
+ * The ::network-status signal is emitted when the network status changes.
+ **/
+	g_signal_new ("network-status",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, network_status),
+		      NULL, NULL,
+		      g_cclosure_marshal_VOID__BOOLEAN,
+		      G_TYPE_NONE,
+		      1,
+		      G_TYPE_BOOLEAN);
+
 	initialised = TRUE;
 	}
 }
@@ -135,18 +152,16 @@ ephy_embed_single_set_offline_mode (EphyEmbedSingle *single,
 }
 
 /**
- * ephy_embed_single_load_proxy_autoconf:
+ * ephy_embed_single_get_offline_mode:
  * @single: the #EphyEmbedSingle
- * @url: a URL to a PAC file
  * 
- * Sets the address of the PAC file, and loads the proxy configuration from it.
+ * Gets the state of the network connection.
  **/
-void
-ephy_embed_single_load_proxy_autoconf (EphyEmbedSingle *single,
-				       const char* url)
+gboolean
+ephy_embed_single_get_offline_mode (EphyEmbedSingle *single)
 {
 	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
-	iface->load_proxy_autoconf (single, url);
+	return iface->get_offline_mode (single);
 }
 
 /**
@@ -169,3 +184,27 @@ ephy_embed_single_get_font_list (EphyEmbedSingle *single,
 	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
 	return iface->get_font_list (single, lang_group);
 }
+
+/**
+ * ephy_embed_single_open_window:
+ * @single: the #EphyEmbedSingle
+ * @parent: the requested window's parent #EphyEmbed
+ * @address: the URL to load
+ * @features: a Javascript features string
+ *
+ * Opens a new window, as if it were opened in @parent using the Javascript
+ * method and arguments: <code>window.open(&quot;@address&quot;,
+ * &quot;_blank&quot;, &quot;@features&quot;);</code>.
+ * 
+ * Use ephy_shell_new_tab() unless this handling of the @features string is
+ * required.
+ */
+void
+ephy_embed_single_open_window (EphyEmbedSingle *single,
+			       EphyEmbed *parent,
+			       const char *address,
+			       const char *features)
+{
+	EphyEmbedSingleIface *iface = EPHY_EMBED_SINGLE_GET_IFACE (single);
+	return iface->open_window (single, parent, address, features);
+}
