@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.20 2004/03/26 22:10:03 adamh Exp $
+ *  $Id: ephy-embed-single.h,v 1.24 2004/07/27 11:04:52 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
 #define EPHY_EMBED_SINGLE_H
 
-#include <glib-object.h>
-#include <glib.h>
+#include "ephy-embed.h"
 
 G_BEGIN_DECLS
 
@@ -46,31 +45,41 @@ struct _EphyEmbedSingleIface
 				     char *mime_type,
 				     char *uri);
 
+	void	 (* network_status) (EphyEmbedSingle *single,
+				     gboolean offline);
+
 	/* Methods */
 
-	void	(* clear_cache)         (EphyEmbedSingle *shell);
-	void	(* clear_auth_cache)	(EphyEmbedSingle *shell);
-	void	(* set_offline_mode)    (EphyEmbedSingle *shell,
-					 gboolean offline);
-	void	(* load_proxy_autoconf) (EphyEmbedSingle *shell,
-					 const char* url);
-	GList *	(* get_font_list)	(EphyEmbedSingle *shell,
-					 const char *langGroup);
+	void	 (* open_window)	 (EphyEmbedSingle *single,
+					  EphyEmbed *parent,
+					  const char *address,
+					  const char *features);
+	void	 (* clear_cache)         (EphyEmbedSingle *shell);
+	void	 (* clear_auth_cache)	 (EphyEmbedSingle *shell);
+	void	 (* set_offline_mode)    (EphyEmbedSingle *shell,
+					  gboolean offline);
+	gboolean (* get_offline_mode)	 (EphyEmbedSingle *single);
+	GList *	 (* get_font_list)	 (EphyEmbedSingle *shell,
+					  const char *langGroup);
 };
 
-GType	ephy_embed_single_get_type		(void);
+GType	 ephy_embed_single_get_type		(void);
 
-void	ephy_embed_single_clear_cache		(EphyEmbedSingle *single);
+void	 ephy_embed_single_open_window		(EphyEmbedSingle *single,
+						 EphyEmbed *parent,
+						 const char *address,
+						 const char *features);
 
-void	ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *single);
+void	 ephy_embed_single_clear_cache		(EphyEmbedSingle *single);
 
-void	ephy_embed_single_set_offline_mode	(EphyEmbedSingle *single,
+void	 ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *single);
+
+void	 ephy_embed_single_set_offline_mode	(EphyEmbedSingle *single,
 						 gboolean offline);
 
-void	ephy_embed_single_load_proxy_autoconf	(EphyEmbedSingle *single,
-						 const char* url);
+gboolean ephy_embed_single_get_offline_mode	(EphyEmbedSingle *single);
 
-GList  *ephy_embed_single_get_font_list		(EphyEmbedSingle *single,
+GList	*ephy_embed_single_get_font_list	(EphyEmbedSingle *single,
 						 const char *lang_group);
 
 G_END_DECLS
