@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.20 2004/06/25 11:31:22 marco Exp $
+ *  $Id: EphyBrowser.h,v 1.21 2004/07/24 10:16:10 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -33,6 +33,7 @@
 #include <nsIDOMDocument.h>
 #include <nsIDOMWindow.h>
 #include <nsIPrintSettings.h>
+#include <nsIRequest.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsIDocShell.h>
@@ -126,12 +127,16 @@ public:
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
+	nsresult SetSecurityInfo (nsIRequest *aRequest);
+	nsresult GetSecurityDescription (nsACString &aDescription);
+
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 
 private:
 	nsCOMPtr<nsIDOMDocument> mTargetDocument;
 	nsCOMPtr<nsIDOMEventReceiver> mEventReceiver;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
+	nsCOMPtr<nsISupports> mSecurityInfo;
 	EphyFaviconEventListener *mFaviconEventListener;
 	EphyPopupBlockEventListener *mPopupBlockEventListener;
 	PRBool mInitialized;
