@@ -16,14 +16,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.73 2004/05/06 13:29:20 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.87 2004/07/30 19:56:08 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "mozilla-embed-single.h"
+#include "mozilla-version.h"
 
 #include "ephy-cookie-manager.h"
 #include "ephy-password-manager.h"
@@ -40,13 +43,18 @@
 #include "ephy-embed-prefs.h"
 #include "MozRegisterComponents.h"
 #include "EphySingle.h"
+#include "EphyBrowser.h"
+#include "EphyUtils.h"
 
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include <nsCOMPtr.h>
+#include <nsMemory.h>
+#include <nsEmbedString.h>
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
+#include <nsIWindowWatcher.h>
 #include <nsIIOService.h>
 #include <nsISupportsPrimitives.h>
 #include <nsICookieManager.h>
@@ -67,16 +75,11 @@
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
 #include <nsIChromeRegistry.h>
 #include <nsILocaleService.h>
-#include <nsIProtocolProxyService.h>
 #include <nsIHttpAuthManager.h>
 #include <nsICacheService.h>
 #include <nsIFontEnumerator.h>
-#endif
-
-#ifdef ALLOW_PRIVATE_STRINGS
-#include <nsString.h>
-#include <nsReadableUtils.h>
-#include <nsNetUtil.h>
+#include <nsNetCID.h>
+#include <nsIIDNService.h>
 #endif
 
 #define MOZILLA_PROFILE_DIR  "/mozilla"
@@ -190,7 +193,7 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
         /* read our predefined default prefs */
         nsresult rv;
         nsCOMPtr<nsILocalFile> file;
-        NS_NewNativeLocalFile(NS_LITERAL_CSTRING(DEFAULT_PROFILE_FILE),
+        NS_NewNativeLocalFile(nsEmbedCString(DEFAULT_PROFILE_FILE),
 			      PR_TRUE, getter_AddRefs(file));
 	if (!file) return FALSE;
 
@@ -219,18 +222,9 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
 	pref->SetCharPref ("general.useragent.vendor", "Epiphany");
 	pref->SetCharPref ("general.useragent.vendorSub", VERSION);
 
-	/* Make sure that Mozilla does not handle these protocols internally */
-	pref->SetBoolPref("network.protocol-handler.external.news", TRUE);
-	pref->SetBoolPref("network.protocol-handler.external.mailto", TRUE);
-	pref->SetBoolPref("network.protocol-handler.external.irc", TRUE);
-	if (have_gnome_url_handler ("ftp"))
-	{
-		pref->SetBoolPref("network.protocol-handler.external.ftp", TRUE);
-	}
-	else
-	{
-		pref->SetBoolPref("network.protocol-handler.external.ftp", FALSE);
-	}
+	/* Open ftp uris with an external handler if one is setup */
+	pref->SetBoolPref("network.protocol-handler.external.ftp",
+			  have_gnome_url_handler ("ftp"));
 
 	return TRUE;
 }
@@ -398,13 +392,13 @@ static nsresult
 mozilla_init_chrome (void)
 {
 	nsresult result;
-	nsAutoString uiLang;
+	nsEmbedString uiLang;
 
 	nsCOMPtr<nsIXULChromeRegistry> chromeRegistry = do_GetService (NS_CHROMEREGISTRY_CONTRACTID);
 	NS_ENSURE_TRUE (chromeRegistry, NS_ERROR_FAILURE);
 
 	// Set skin to 'classic' so we get native scrollbars.
-	result = chromeRegistry->SelectSkin (NS_LITERAL_CSTRING("classic/1.0"), PR_FALSE);
+	result = chromeRegistry->SelectSkin (nsEmbedCString("classic/1.0"), PR_FALSE);
 	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
 
 	// set locale
@@ -414,17 +408,26 @@ mozilla_init_chrome (void)
 	result = getUILang(uiLang);
 	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
 
-	return chromeRegistry->SelectLocale (NS_ConvertUTF16toUTF8(uiLang), PR_FALSE);
+	nsEmbedCString cUILang;
+	NS_UTF16ToCString (uiLang, NS_CSTRING_ENCODING_UTF8, cUILang);
+
+	return chromeRegistry->SelectLocale (cUILang, PR_FALSE);
 }
 
 static void
 mozilla_init_observer (MozillaEmbedSingle *single)
 {
-	single->priv->mSingleObserver = new EphySingle ();
+	EphySingle *es;
 
-	if (single->priv->mSingleObserver)
+	es = new EphySingle ();
+	NS_ADDREF (single->priv->mSingleObserver = es);
+
+	nsresult rv;
+	rv = es->Init (EPHY_EMBED_SINGLE (single));
+	if (NS_FAILED (rv))
 	{
-		single->priv->mSingleObserver->Init (EPHY_EMBED_SINGLE (single));
+		g_warning ("Failed to initialise EphySingle!\n");
+		return;
 	}
 }
 
@@ -497,6 +500,19 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 	}
 }
 
+static void
+mozilla_embed_single_dispose (GObject *object)
+{
+	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (object);
+
+	if (single->priv->mSingleObserver)
+	{
+		single->priv->mSingleObserver->Detach ();
+		NS_RELEASE (single->priv->mSingleObserver);
+		single->priv->mSingleObserver = nsnull;
+	}
+}
+
 static void
 mozilla_embed_single_finalize (GObject *object)
 {
@@ -548,17 +564,18 @@ impl_set_offline_mode (EphyEmbedSingle *shell,
 	io->SetOffline(offline);
 }
 
-static void
-impl_load_proxy_autoconf (EphyEmbedSingle *shell,
-			  const char* url)
+static gboolean
+impl_get_offline_mode (EphyEmbedSingle *shell)
 {
-	g_assert (url != NULL);
+	nsCOMPtr<nsIIOService> io = do_GetService(NS_IOSERVICE_CONTRACTID);
+	if (!io) return FALSE; /* no way to check the state, assume offline */
 
-        nsCOMPtr<nsIProtocolProxyService> pps =
-                do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
-	if (!pps) return;
+	PRBool isOffline;
+	nsresult rv;
+	rv = io->GetOffline(&isOffline);
+	NS_ENSURE_SUCCESS (rv, FALSE);
 
-	pps->ConfigureFromPAC (url);
+	return isOffline;
 }
 
 static GList *
@@ -582,7 +599,10 @@ impl_get_font_list (EphyEmbedSingle *shell,
 	{
 		char *gFontString;
 
-		gFontString = g_strdup (NS_ConvertUTF16toUTF8 (fontArray[i]).get());
+		nsEmbedCString tmp;
+		NS_UTF16ToCString (nsEmbedString(fontArray[i]),
+				   NS_CSTRING_ENCODING_UTF8, tmp);
+		gFontString = g_strdup (tmp.get());
 		l = g_list_prepend (l, gFontString);
 		nsMemory::Free (fontArray[i]);
 	}
@@ -616,6 +636,7 @@ impl_list_cookies (EphyCookieManager *manager)
 		if (NS_FAILED (result) || !keks) continue;
 
 		EphyCookie *cookie = mozilla_cookie_to_ephy_cookie (keks);
+		if (!cookie) continue;
 
 		cookies = g_list_prepend (cookies, cookie);
 	}       
@@ -631,9 +652,18 @@ impl_remove_cookie (EphyCookieManager *manager,
 		do_GetService (NS_COOKIEMANAGER_CONTRACTID);
 	if (!cookieManager) return;
 
-	cookieManager->Remove (nsDependentCString(cookie->domain),
-			       nsDependentCString(cookie->name),
-			       nsDependentCString(cookie->path),
+	nsCOMPtr<nsIIDNService> idnService
+		(do_GetService ("@mozilla.org/network/idn-service;1"));
+	NS_ENSURE_TRUE (idnService, );
+
+	nsresult rv;
+	nsEmbedCString host;
+	rv = idnService->ConvertUTF8toACE (nsEmbedCString(cookie->domain), host);
+	NS_ENSURE_SUCCESS (rv, );
+
+	cookieManager->Remove (host,
+			       nsEmbedCString(cookie->name),
+			       nsEmbedCString(cookie->path),
 			       PR_FALSE /* block */);
 }
 
@@ -659,6 +689,10 @@ impl_list_passwords (EphyPasswordManager *manager)
 			do_GetService (NS_PASSWORDMANAGER_CONTRACTID);
 	if (!passwordManager) return NULL;
 
+	nsCOMPtr<nsIIDNService> idnService
+		(do_GetService ("@mozilla.org/network/idn-service;1"));
+	NS_ENSURE_TRUE (idnService, NULL);
+
 	nsCOMPtr<nsISimpleEnumerator> passwordEnumerator;
 	passwordManager->GetEnumerator (getter_AddRefs(passwordEnumerator));
 	NS_ENSURE_TRUE (passwordEnumerator, NULL);
@@ -672,18 +706,25 @@ impl_list_passwords (EphyPasswordManager *manager)
 		passwordEnumerator->GetNext (getter_AddRefs(nsPassword));
 		if (!nsPassword) continue;
 
-		nsCAutoString transfer;
+		nsEmbedCString transfer;
 		rv = nsPassword->GetHost (transfer);
 		if (NS_FAILED (rv)) continue;
 
-		nsAutoString unicodeName;
+		nsEmbedCString host;
+		idnService->ConvertACEtoUTF8 (transfer, host);
+
+		nsEmbedString unicodeName;
 		rv = nsPassword->GetUser (unicodeName);
 		if (NS_FAILED (rv)) continue;
 
+		nsEmbedCString userName;
+		NS_UTF16ToCString (unicodeName,
+				   NS_CSTRING_ENCODING_UTF8, userName);
+
 		EphyPasswordInfo *p = g_new0 (EphyPasswordInfo, 1);
 
-		p->host = g_strdup (transfer.get());
-		p->username = g_strdup(NS_ConvertUTF16toUTF8(unicodeName).get());
+		p->host = g_strdup (host.get());
+		p->username = g_strdup (userName.get());
 		p->password = NULL;
 
 		passwords = g_list_prepend (passwords, p);
@@ -701,55 +742,59 @@ impl_remove_password (EphyPasswordManager *manager,
                         do_GetService (NS_PASSWORDMANAGER_CONTRACTID);
 	if (!pm) return;
 
-	pm->RemoveUser (nsDependentCString(info->host),
-			NS_ConvertUTF8toUTF16(nsDependentCString(info->username)));
+	nsCOMPtr<nsIIDNService> idnService
+		(do_GetService ("@mozilla.org/network/idn-service;1"));
+	NS_ENSURE_TRUE (idnService, );
+
+	nsresult rv;
+	nsEmbedCString host;
+	rv = idnService->ConvertUTF8toACE (nsEmbedCString(info->host), host);
+	NS_ENSURE_SUCCESS (rv, );
+
+	nsEmbedString userName;
+	NS_CStringToUTF16 (nsEmbedCString(info->username),
+			   NS_CSTRING_ENCODING_UTF8, userName);
+	pm->RemoveUser (host, userName);
 }
 
-static const char *permission_type_string [] =
-{
-	"cookie",
-	"image",
-	"popup"
-};
-
-void
+static void
 impl_permission_manager_add (EphyPermissionManager *manager,
 			     const char *host,
-			     EphyPermissionType type,
+			     const char *type,
 			     EphyPermission permission)
 {
 	/* can only set allow or deny */
 	g_return_if_fail (permission != EPHY_PERMISSION_DEFAULT);
+	g_return_if_fail (type != NULL && type[0] != '\0');
 
         nsCOMPtr<nsIPermissionManager> pm
 		(do_GetService (NS_PERMISSIONMANAGER_CONTRACTID));
 	if (!pm) return;
 
 	nsCOMPtr<nsIURI> uri;
-        NS_NewURI(getter_AddRefs(uri), host);
+        EphyUtils::NewURI(getter_AddRefs(uri), nsEmbedCString(host));
 	if (!uri) return;
 
 	gboolean allow = (permission == EPHY_PERMISSION_ALLOWED);
 
-	pm->Add (uri,
-		 permission_type_string [type],
+	pm->Add (uri, type,
 		 allow ? (PRUint32) nsIPermissionManager::ALLOW_ACTION :
 			 (PRUint32) nsIPermissionManager::DENY_ACTION);
 }
 
-void
+static void
 impl_permission_manager_remove (EphyPermissionManager *manager,
 				const char *host,
-				EphyPermissionType type)
+				const char *type)
 {
         nsCOMPtr<nsIPermissionManager> pm
 		(do_GetService (NS_PERMISSIONMANAGER_CONTRACTID));
 	if (!pm) return;
 
-	pm->Remove (nsDependentCString (host), permission_type_string [type]);
+	pm->Remove (nsEmbedCString (host), type);
 }
 
-void
+static void
 impl_permission_manager_clear (EphyPermissionManager *manager)
 {
         nsCOMPtr<nsIPermissionManager> pm
@@ -762,19 +807,21 @@ impl_permission_manager_clear (EphyPermissionManager *manager)
 EphyPermission
 impl_permission_manager_test (EphyPermissionManager *manager,
 			      const char *host,
-			      EphyPermissionType type)
+			      const char *type)
 {
+	g_return_val_if_fail (type != NULL && type[0] != '\0', EPHY_PERMISSION_DEFAULT);
+
         nsCOMPtr<nsIPermissionManager> pm
 		(do_GetService (NS_PERMISSIONMANAGER_CONTRACTID));
 	if (!pm) return EPHY_PERMISSION_DEFAULT;
 
 	nsCOMPtr<nsIURI> uri;
-        NS_NewURI(getter_AddRefs(uri), host);
+        EphyUtils::NewURI(getter_AddRefs(uri), nsEmbedCString (host));
         if (!uri) return EPHY_PERMISSION_DEFAULT;
 
 	nsresult rv;
 	PRUint32 action;
-	rv = pm->TestPermission (uri, permission_type_string [type], &action);
+	rv = pm->TestPermission (uri, type, &action);
 	NS_ENSURE_SUCCESS (rv, EPHY_PERMISSION_DEFAULT);
 
 	EphyPermission permission;
@@ -798,7 +845,7 @@ impl_permission_manager_test (EphyPermissionManager *manager,
 
 GList *
 impl_permission_manager_list (EphyPermissionManager *manager,
-			      EphyPermissionType type)
+			      const char *type)
 {
 	GList *list = NULL;
 
@@ -810,19 +857,21 @@ impl_permission_manager_list (EphyPermissionManager *manager,
 	pm->GetEnumerator(getter_AddRefs(pe));
 	NS_ENSURE_TRUE (pe, NULL);
 	
-	PRBool more;
-	for (pe->HasMoreElements (&more); more == PR_TRUE; pe->HasMoreElements (&more))
+	PRBool hasMore;
+	while (NS_SUCCEEDED (pe->HasMoreElements (&hasMore)) && hasMore)
 	{
-		nsCOMPtr<nsIPermission> perm;
-		pe->GetNext(getter_AddRefs(perm));
+		nsCOMPtr<nsISupports> element;
+		pe->GetNext (getter_AddRefs (element));
+		
+		nsCOMPtr<nsIPermission> perm (do_QueryInterface (element));
 		if (!perm) continue;
 
 		nsresult rv;
-		nsCAutoString str;
+		nsEmbedCString str;
 		rv = perm->GetType(str);
 		if (NS_FAILED (rv)) continue;
 
-		if (str.Equals(permission_type_string[type]))
+		if (strcmp (str.get(), type) == 0)
 		{
 			EphyPermissionInfo *info = 
 				mozilla_permission_to_ephy_permission (perm);
@@ -837,6 +886,30 @@ impl_permission_manager_list (EphyPermissionManager *manager,
 	return list;
 }
 
+static void
+impl_open_window (EphyEmbedSingle *single,
+		  EphyEmbed *parent,
+		  const char *address,
+		  const char *features)
+{
+	nsCOMPtr<nsIDOMWindow> domWindow;
+	nsCOMPtr<nsIDOMWindow> dummy;
+
+	if (parent)
+	{
+		EphyBrowser *browser;
+
+		browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(parent));
+		g_return_if_fail (browser != NULL);
+
+		browser->GetDOMWindow (getter_AddRefs (domWindow));
+	}
+
+	nsCOMPtr<nsIWindowWatcher> wWatch(do_GetService ("@mozilla.org/embedcomp/window-watcher;1"));
+	wWatch->OpenWindow (domWindow, address, "", features, nsnull,
+			    getter_AddRefs (dummy));
+}
+
 static void
 mozilla_embed_single_class_init (MozillaEmbedSingleClass *klass)
 {
@@ -844,6 +917,7 @@ mozilla_embed_single_class_init (MozillaEmbedSingleClass *klass)
 
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
+	object_class->dispose = mozilla_embed_single_dispose;
 	object_class->finalize = mozilla_embed_single_finalize;
 
 	g_type_class_add_private (object_class, sizeof (MozillaEmbedSinglePrivate));
@@ -855,8 +929,9 @@ ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 	iface->clear_cache = impl_clear_cache;
 	iface->clear_auth_cache = impl_clear_auth_cache;
 	iface->set_offline_mode = impl_set_offline_mode;
-	iface->load_proxy_autoconf = impl_load_proxy_autoconf;
+	iface->get_offline_mode = impl_get_offline_mode;
 	iface->get_font_list = impl_get_font_list;
+	iface->open_window = impl_open_window;
 }
 
 static void
