@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.138 2004/06/24 10:03:31 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.140 2004/07/23 10:49:39 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -286,7 +286,7 @@ cmd_add_topic (GtkAction *action,
 	node = ephy_bookmarks_add_keyword (editor->priv->bookmarks,
 				           _("Type a topic"));
 	ephy_node_view_select_node (EPHY_NODE_VIEW (editor->priv->key_view), node);
-	ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view));
+	ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view), TRUE);
 	add_text_renderer_monitor (editor);
 }
 
@@ -303,11 +303,11 @@ cmd_rename (GtkAction *action,
 {
 	if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->bm_view)))
 	{
-		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->bm_view));
+		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->bm_view), FALSE);
 	}
 	else if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->key_view)))
 	{
-		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view));
+		ephy_node_view_edit (EPHY_NODE_VIEW (editor->priv->key_view), FALSE);
 	}
 	add_text_renderer_monitor (editor);
 }
@@ -1500,10 +1500,13 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	ephy_node_view_add_column (EPHY_NODE_VIEW (key_view), _("Topics"),
 				   G_TYPE_STRING,
 				   EPHY_NODE_KEYWORD_PROP_NAME,
-				   EPHY_NODE_KEYWORD_PROP_PRIORITY,
-				   EPHY_NODE_VIEW_AUTO_SORT |
+				   EPHY_NODE_VIEW_SHOW_PRIORITY |
 				   EPHY_NODE_VIEW_EDITABLE |
 				   EPHY_NODE_VIEW_SEARCHABLE, NULL);
+	ephy_node_view_set_priority (EPHY_NODE_VIEW (key_view),
+				     EPHY_NODE_KEYWORD_PROP_PRIORITY);
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (key_view), G_TYPE_STRING,
+				 EPHY_NODE_KEYWORD_PROP_NAME, GTK_SORT_ASCENDING);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), key_view);
 	gtk_widget_set_size_request (key_view, 130, -1);
 	gtk_widget_show (key_view);
@@ -1560,15 +1563,16 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 					   col_id);
 	editor->priv->title_col = ephy_node_view_add_column
 				  (EPHY_NODE_VIEW (bm_view), _("Title"),
-				   G_TYPE_STRING, EPHY_NODE_BMK_PROP_TITLE, -1,
-				   EPHY_NODE_VIEW_AUTO_SORT |
+				   G_TYPE_STRING, EPHY_NODE_BMK_PROP_TITLE,
 				   EPHY_NODE_VIEW_EDITABLE |
 				   EPHY_NODE_VIEW_SEARCHABLE,
 				   provide_favicon);
 	editor->priv->address_col = ephy_node_view_add_column
 				  (EPHY_NODE_VIEW (bm_view), _("Address"),
 				   G_TYPE_STRING, EPHY_NODE_BMK_PROP_LOCATION,
-				   -1, 0, NULL);
+				   0, NULL);
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (bm_view), G_TYPE_STRING,
+				 EPHY_NODE_BMK_PROP_TITLE, GTK_SORT_ASCENDING);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), bm_view);
 	gtk_widget_show (bm_view);
 	editor->priv->bm_view = bm_view;
