@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000, 2001, 2002, 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000, 2001, 2002, 2003, 2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.169.4.9 2004/07/31 19:01:43 chpe Exp $
+ *  $Id: ephy-window.c,v 1.202 2004/07/31 19:03:36 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,6 +33,8 @@
 #include "window-commands.h"
 #include "find-dialog.h"
 #include "print-dialog.h"
+#include "ephy-embed-shell.h"
+#include "ephy-embed-single.h"
 #include "ephy-shell.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
@@ -40,7 +43,9 @@
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
 #include "ephy-statusbar.h"
+#include "egg-editable-toolbar.h"
 #include "toolbar.h"
+#include "ephy-bookmarksbar.h"
 #include "popup-commands.h"
 #include "ephy-encoding-menu.h"
 #include "ephy-tabs-menu.h"
@@ -76,6 +81,8 @@ static void ephy_window_view_toolbar_cb         (GtkAction *action,
 			                         EphyWindow *window);
 static void ephy_window_view_bookmarksbar_cb    (GtkAction *action,
 			                         EphyWindow *window);
+static void ephy_window_view_popup_windows_cb	(GtkAction *action,
+						 EphyWindow *window);
 
 static GtkActionEntry ephy_menu_entries [] = {
 
@@ -103,6 +110,9 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "FileSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<shift><control>S",
 	  N_("Save the current page"),
 	  G_CALLBACK (window_cmd_file_save_as) },
+	{ "FileSave", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<control>S",
+	  N_("Save the current page"),
+	  G_CALLBACK (window_cmd_file_save_as) },
 	{ "FilePrintSetup", STOCK_PRINT_SETUP, N_("Print Set_up..."), NULL,
 	  N_("Setup the page settings for printing"),
 	  G_CALLBACK (window_cmd_file_print_setup) },
@@ -237,6 +247,11 @@ static guint ephy_menu_n_entries = G_N_ELEMENTS (ephy_menu_entries);
 
 static GtkToggleActionEntry ephy_menu_toggle_entries [] =
 {
+	/* File Menu */
+	{ "FileWorkOffline", NULL, N_("_Work Offline"), NULL,
+	  N_("Toggle network status"),
+	  G_CALLBACK (window_cmd_file_work_offline), FALSE },
+
 	/* View Menu */
 	{ "ViewToolbar", NULL, N_("_Toolbar"), "<shift><control>T",
 	  N_("Show or hide toolbar"),
@@ -250,6 +265,9 @@ static GtkToggleActionEntry ephy_menu_toggle_entries [] =
 	{ "ViewFullscreen", STOCK_FULLSCREEN, N_("_Fullscreen"), "F11",
 	  N_("Browse at full screen"),
 	  G_CALLBACK (window_cmd_view_fullscreen), FALSE },
+	{ "ViewPopupWindows", EPHY_STOCK_POPUPS, N_("Popup _Windows"), NULL,
+	  N_("Show or hide unrequested popup windows from this site"),
+	  G_CALLBACK (ephy_window_view_popup_windows_cb), FALSE },
 	{ "BrowseWithCaret", NULL, N_("Selection Caret"), "F7",
 	  "",
 	  G_CALLBACK (window_cmd_browse_with_caret), FALSE }
@@ -267,10 +285,6 @@ static GtkActionEntry ephy_popups_entries [] = {
 	/* Framed document */
 	{ "OpenFrame", NULL, N_("_Open Frame"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_open_frame) },
-	{ "OpenFrameInNewWindow", NULL, N_("Open Frame in _New Window"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_frame_in_new_window) },
-	{ "OpenFrameInNewTab", NULL, N_("Open Frame in New _Tab"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_frame_in_new_tab) },
 
 	/* Links */
 	{ "OpenLink", GTK_STOCK_OPEN, N_("_Open Link"),
@@ -291,10 +305,6 @@ static GtkActionEntry ephy_popups_entries [] = {
 	/* Images */
 	{ "OpenImage", GTK_STOCK_OPEN, N_("Open _Image"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_open_image) },
-	{ "OpenImageInNewWindow", NULL, N_("Open Image in New _Window"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_image_in_new_window) },
-	{ "OpenImageInNewTab", NULL, N_("Open Image in New T_ab"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_image_in_new_tab) },
 	{ "SaveImageAs", GTK_STOCK_SAVE_AS, N_("_Save Image As..."), NULL,
 	  NULL, G_CALLBACK (popup_cmd_save_image_as) },
 	{ "SetImageAsBackground", NULL, N_("_Use Image As Background"), NULL,
@@ -306,6 +316,7 @@ static guint ephy_popups_n_entries = G_N_ELEMENTS (ephy_popups_entries);
 
 #define CONF_LOCKDOWN_HIDE_MENUBAR "/apps/epiphany/lockdown/hide_menubar"
 #define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
+#define INSANE_NUMBER_OF_URLS 20
 
 #define EPHY_WINDOW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_WINDOW, EphyWindowPrivate))
 
@@ -323,6 +334,7 @@ struct EphyWindowPrivate
 	GtkWidget *menu_dock;
 	GtkWidget *exit_fullscreen_popup;
 	Toolbar *toolbar;
+	GtkWidget *bookmarksbar;
 	GtkWidget *statusbar;
 	GtkActionGroup *action_group;
 	GtkActionGroup *popups_action_group;
@@ -352,6 +364,7 @@ struct EphyWindowPrivate
 	guint disable_save_to_disk_notifier_id;
 	guint disable_command_line_notifier_id;
 	guint browse_with_caret_notifier_id;
+	guint allow_popups_notifier_id;
 };
 
 enum
@@ -366,9 +379,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_window_get_type (void)
 {
-        static GType ephy_window_type = 0;
+        static GType type = 0;
 
-        if (ephy_window_type == 0)
+        if (type == 0)
         {
                 static const GTypeInfo our_info =
                 {
@@ -383,40 +396,67 @@ ephy_window_get_type (void)
                         (GInstanceInitFunc) ephy_window_init
                 };
 
-                ephy_window_type = g_type_register_static (GTK_TYPE_WINDOW,
-							   "EphyWindow",
-							   &our_info, 0);
+                type = g_type_register_static (GTK_TYPE_WINDOW,
+					       "EphyWindow",
+					       &our_info, 0);
         }
-        return ephy_window_type;
+
+        return type;
 }
 
 static void
 update_exit_fullscreen_popup_position (EphyWindow *window)
 {
+	GtkWidget *popup = window->priv->exit_fullscreen_popup;
 	GdkRectangle screen_rect;
-        int popup_height;
+	int popup_width, popup_height;
 
-        g_return_if_fail (window->priv->exit_fullscreen_popup != NULL);
+	g_return_if_fail (popup != NULL);
 
-        gtk_window_get_size (GTK_WINDOW (window->priv->exit_fullscreen_popup),
-                             NULL, &popup_height);
+	gtk_window_get_size (GTK_WINDOW (popup), &popup_width, &popup_height);
 
-        gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
+	/* FIXME multihead */
+	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
                         gdk_screen_get_monitor_at_window
                         (gdk_screen_get_default (),
                          GTK_WIDGET (window)->window),
                          &screen_rect);
 
-        gtk_window_move (GTK_WINDOW (window->priv->exit_fullscreen_popup),
-                        screen_rect.x, screen_rect.height - popup_height);
+	if (gtk_widget_get_direction (popup) == GTK_TEXT_DIR_RTL)
+	{
+		gtk_window_move (GTK_WINDOW (popup),
+				 screen_rect.x + screen_rect.width - popup_width,
+				 screen_rect.height - popup_height);
+	}
+	else
+	{
+		gtk_window_move (GTK_WINDOW (popup),
+                	        screen_rect.x, screen_rect.height - popup_height);
+	}
 }
 
 static void
-size_changed_cb (GdkScreen *screen, EphyWindow *window)
+screen_size_changed_cb (GdkScreen *screen,
+			EphyWindow *window)
 {
 	update_exit_fullscreen_popup_position (window);
 }
 
+static void
+destroy_exit_fullscreen_popup (EphyWindow *window)
+{
+	if (window->priv->exit_fullscreen_popup != NULL)
+	{
+		/* FIXME multihead */
+		g_signal_handlers_disconnect_by_func
+			(gdk_screen_get_default (),
+			 G_CALLBACK (screen_size_changed_cb), window);
+
+		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
+		window->priv->exit_fullscreen_popup = NULL;
+	}
+}
+
 static void
 ephy_window_destroy (GtkObject *gtkobject)
 {
@@ -435,15 +475,7 @@ ephy_window_destroy (GtkObject *gtkobject)
 		ephy_extension_detach_window (manager, window);
 	}
 
-	if (window->priv->exit_fullscreen_popup)
-	{
-		g_signal_handlers_disconnect_by_func
-			(gdk_screen_get_default (),
-			 G_CALLBACK (size_changed_cb), window);
-
-		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
-		window->priv->exit_fullscreen_popup = NULL;
-	}
+	destroy_exit_fullscreen_popup (window);
 
         GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
 }
@@ -458,7 +490,12 @@ add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
 static void
 exit_fullscreen_button_clicked_cb (GtkWidget *button, EphyWindow *window)
 {
-	gtk_window_unfullscreen (GTK_WINDOW (window));
+	GtkAction *action;
+
+	action = gtk_action_group_get_action (window->priv->action_group, "ViewFullscreen");
+	g_return_if_fail (action != NULL);
+
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), FALSE);
 }
 
 static void
@@ -471,17 +508,18 @@ get_chromes_visibility (EphyWindow *window, gboolean *show_menubar,
 	switch (window->priv->mode)
 	{
 		case EPHY_WINDOW_MODE_NORMAL:
-			*show_menubar = flags & EPHY_EMBED_CHROME_MENUBAR;
-			*show_statusbar = flags & EPHY_EMBED_CHROME_STATUSBAR;
-			*show_toolbar = flags & EPHY_EMBED_CHROME_TOOLBAR;
-			*show_bookmarksbar = flags & EPHY_EMBED_CHROME_BOOKMARKSBAR;
+			*show_menubar = (flags & EPHY_EMBED_CHROME_MENUBAR) != 0;
+			*show_statusbar = (flags & EPHY_EMBED_CHROME_STATUSBAR) != 0;
+			*show_toolbar = (flags & EPHY_EMBED_CHROME_TOOLBAR) != 0;
+			*show_bookmarksbar = (flags & EPHY_EMBED_CHROME_BOOKMARKSBAR) != 0;
 			break;
 		case EPHY_WINDOW_MODE_FULLSCREEN:
-			*show_toolbar = flags & EPHY_EMBED_CHROME_TOOLBAR;
+			*show_toolbar = (flags & EPHY_EMBED_CHROME_TOOLBAR) != 0;
 			*show_menubar = *show_statusbar = *show_bookmarksbar = FALSE;
 			break;
 		default:
 			*show_menubar = *show_statusbar = *show_toolbar = *show_bookmarksbar = FALSE;
+			break;
 	}
 }
 
@@ -499,27 +537,10 @@ sync_chromes_visibility (EphyWindow *window)
 		(GTK_UI_MANAGER (window->ui_merge), "/menubar");
 	g_assert (menubar != NULL);
 
-	if (show_menubar)
-	{
-		gtk_widget_show (menubar);
-	}
-	else
-	{
-		gtk_widget_hide (menubar);
-	}
-
-	toolbar_set_visibility (window->priv->toolbar, show_toolbar,
-				show_bookmarksbar);
-
-
-	if (show_statusbar)
-	{
-		gtk_widget_show (window->priv->statusbar);
-	}
-	else
-	{
-		gtk_widget_hide (window->priv->statusbar);
-	}
+	g_object_set (G_OBJECT (menubar), "visible", show_menubar, NULL);
+	g_object_set (G_OBJECT (window->priv->toolbar), "visible", show_toolbar, NULL);
+	g_object_set (G_OBJECT (window->priv->bookmarksbar), "visible", show_bookmarksbar, NULL);
+	g_object_set (G_OBJECT (window->priv->statusbar), "visible", show_statusbar, NULL);
 }
 
 static void
@@ -529,6 +550,14 @@ ephy_window_fullscreen (EphyWindow *window)
 
 	window->priv->mode = EPHY_WINDOW_MODE_FULLSCREEN;
 
+	sync_chromes_visibility (window);
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN))
+	{
+		/* no need to show "exit fullscreen" button */
+		return;
+	}
+
 	popup = gtk_window_new (GTK_WINDOW_POPUP);
 	window->priv->exit_fullscreen_popup = popup;
 
@@ -551,15 +580,21 @@ ephy_window_fullscreen (EphyWindow *window)
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
+	gtk_window_set_resizable (GTK_WINDOW (popup), FALSE);
+
+	/* FIXME multihead */
+	g_signal_connect (gdk_screen_get_default (), "size-changed",
+			  G_CALLBACK (screen_size_changed_cb), window);
+
 	update_exit_fullscreen_popup_position (window);
 
 	gtk_widget_show (popup);
 
-	g_signal_connect (G_OBJECT (gdk_screen_get_default ()),
-                          "size-changed", G_CALLBACK (size_changed_cb),
-			  window);
 
-	sync_chromes_visibility (window);
+	egg_editable_toolbar_set_model
+		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
+		 EGG_TOOLBARS_MODEL (
+		 	ephy_shell_get_toolbars_model (ephy_shell, TRUE)));
 }
 
 static void
@@ -567,12 +602,12 @@ ephy_window_unfullscreen (EphyWindow *window)
 {
 	window->priv->mode = EPHY_WINDOW_MODE_NORMAL;
 
-	g_signal_handlers_disconnect_by_func (G_OBJECT (gdk_screen_get_default ()),
-                                              G_CALLBACK (size_changed_cb),
-					      window);
+	destroy_exit_fullscreen_popup (window);
 
-	gtk_widget_destroy (window->priv->exit_fullscreen_popup);
-	window->priv->exit_fullscreen_popup = NULL;
+	egg_editable_toolbar_set_model
+		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
+		 EGG_TOOLBARS_MODEL (
+		 	ephy_shell_get_toolbars_model (ephy_shell, FALSE)));
 
 	sync_chromes_visibility (window);
 }
@@ -600,7 +635,11 @@ ephy_window_state_event_cb (GtkWidget *widget, GdkEventWindowState *event, EphyW
 		action_group = window->priv->action_group;
 
 		action = gtk_action_group_get_action (action_group, "ViewFullscreen");
+		g_signal_handlers_block_by_func
+			(action, G_CALLBACK (window_cmd_view_fullscreen), window);
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), fullscreen);
+		g_signal_handlers_unblock_by_func
+			(action, G_CALLBACK (window_cmd_view_fullscreen), window);
 
 		action = gtk_action_group_get_action (action_group, "EditToolbar");
 		g_object_set (action, "sensitive", !fullscreen, NULL);
@@ -621,7 +660,7 @@ confirm_close_with_modified_forms (EphyWindow *window)
 					      GTK_WINDOW (window),
 					      GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_MODAL,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      _("_Close document"), GTK_RESPONSE_OK,
+					      _("Close _Document"), GTK_RESPONSE_OK,
 					      NULL);
 	
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -644,6 +683,7 @@ confirm_close_with_modified_forms (EphyWindow *window)
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
 	label = gtk_label_new (NULL);
+	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
@@ -663,6 +703,48 @@ confirm_close_with_modified_forms (EphyWindow *window)
 	return response == GTK_RESPONSE_OK;
 }
 
+static void
+menubar_deactivate_cb (GtkWidget *menubar,
+		       EphyWindow *window)
+{
+	g_signal_handlers_disconnect_by_func
+		(menubar, G_CALLBACK (menubar_deactivate_cb), window);
+
+	gtk_menu_shell_deselect (GTK_MENU_SHELL (menubar));
+
+	sync_chromes_visibility (window);
+}
+
+static gboolean
+ephy_window_key_press_event (GtkWidget *widget,
+			     GdkEventKey *event)
+{
+	EphyWindow *window = EPHY_WINDOW (widget);
+	GtkWidget *menubar;
+	guint modifiers = gtk_accelerator_get_default_mod_mask ();
+
+	/* Show and activate the menubar on F10, if it isn't visible */
+        if (event->keyval == GDK_F10 && (event->state & modifiers) == 0)
+	{
+		menubar = gtk_ui_manager_get_widget
+			(GTK_UI_MANAGER (window->ui_merge), "/menubar");
+		g_return_val_if_fail (menubar != NULL , FALSE);
+	
+		if (!GTK_WIDGET_VISIBLE (menubar))
+		{
+			g_signal_connect (menubar, "deactivate",
+					  G_CALLBACK (menubar_deactivate_cb), window);
+
+			gtk_widget_show (menubar);
+			gtk_menu_shell_select_first (GTK_MENU_SHELL (menubar), FALSE);
+
+			return TRUE;
+		}
+        }
+
+	return GTK_WIDGET_CLASS (parent_class)->key_press_event (widget, event);
+}
+
 static gboolean
 ephy_window_delete_event_cb (GtkWidget *widget, GdkEvent *event, EphyWindow *window)
 {
@@ -885,7 +967,7 @@ connect_proxy_cb (GtkUIManager *manager,
 static void
 update_chromes_actions (EphyWindow *window)
 {
-	GtkActionGroup *action_group = GTK_ACTION_GROUP (window->priv->action_group);
+	GtkActionGroup *action_group = window->priv->action_group;
 	GtkAction *action;
 	gboolean show_statusbar, show_menubar, show_toolbar, show_bookmarksbar;
 
@@ -924,11 +1006,11 @@ update_chromes_actions (EphyWindow *window)
 static void
 update_actions_sensitivity (EphyWindow *window)
 {
-	GtkActionGroup *action_group = GTK_ACTION_GROUP (window->priv->action_group);
-	GtkActionGroup *popups_action_group = GTK_ACTION_GROUP (window->priv->popups_action_group);
+	GtkActionGroup *action_group = window->priv->action_group;
+	GtkActionGroup *popups_action_group = window->priv->popups_action_group;
 	GtkAction *action;
 	gboolean bookmarks_editable, save_to_disk;
-	gboolean printing, print_setup;
+	gboolean printing, print_setup, fullscreen;
 
 	action = gtk_action_group_get_action (action_group, "ViewToolbar");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_TOOLBARS), NULL);
@@ -980,6 +1062,14 @@ update_actions_sensitivity (EphyWindow *window)
 
 	action = gtk_action_group_get_action (action_group, "EditToolbar");
 	g_object_set (action, "sensitive", ! eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_TOOLBAR_EDITING), NULL);
+
+	fullscreen = eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
+	action = gtk_action_group_get_action (action_group, "FileNewWindow");
+	g_object_set (action, "sensitive", !fullscreen, NULL);
+	action = gtk_action_group_get_action (action_group, "ViewFullscreen");
+	g_object_set (action, "sensitive", !fullscreen, NULL);
+	action = gtk_action_group_get_action (action_group, "TabsDetach");
+	g_object_set (action, "sensitive", !fullscreen, NULL);
 }
 
 static void
@@ -1251,6 +1341,64 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 }
 
+static void
+sync_tab_popup_windows (EphyTab *tab,
+			GParamSpec *pspec,
+			EphyWindow *window)
+{
+	guint num_popups = 0;
+	char *tooltip = NULL;
+
+	g_object_get (G_OBJECT (tab),
+		      "hidden-popup-count", &num_popups,
+		      NULL);
+
+	if (num_popups > 0)
+	{
+		tooltip = g_strdup_printf (ngettext ("%d hidden popup window",
+						     "%d hidden popup windows",
+						     num_popups),
+					   num_popups);
+	}
+
+	ephy_statusbar_set_popups_state
+		(EPHY_STATUSBAR (window->priv->statusbar),
+		 tooltip == NULL,
+		 tooltip);
+
+	g_free (tooltip);
+}
+
+static void
+sync_tab_popups_allowed (EphyTab *tab,
+			 GParamSpec *pspec,
+			 EphyWindow *window)
+{
+	GtkAction *action;
+	gboolean allow;
+
+	g_return_if_fail (EPHY_IS_TAB (tab));
+	g_return_if_fail (EPHY_IS_WINDOW (window));
+
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "ViewPopupWindows");
+	g_return_if_fail (GTK_IS_ACTION (action));
+
+	g_object_get (G_OBJECT (tab), "popups-allowed", &allow, NULL);
+
+	g_signal_handlers_block_by_func
+		(G_OBJECT (action),
+		 G_CALLBACK (ephy_window_view_popup_windows_cb),
+		 window);
+
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), allow);
+
+	g_signal_handlers_unblock_by_func
+		(G_OBJECT (action),
+		 G_CALLBACK (ephy_window_view_popup_windows_cb),
+		 window);
+}
+
 static void
 sync_tab_load_status (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
@@ -1358,6 +1506,22 @@ sync_tab_zoom (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	g_object_set (action, "sensitive", can_zoom_normal, NULL);
 }
 
+static void
+network_status_changed (EphyEmbedSingle *single,
+			gboolean offline,
+			EphyWindow *window)
+{
+	GtkAction *action;
+
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "FileWorkOffline");
+	g_signal_handlers_block_by_func
+		(action, G_CALLBACK (window_cmd_file_work_offline), window);
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), offline);
+	g_signal_handlers_unblock_by_func
+		(action, G_CALLBACK (window_cmd_file_work_offline), window);	
+}
+
 static void
 popup_menu_at_coords (GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 		      gpointer user_data)
@@ -1402,6 +1566,8 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 
 	context = ephy_embed_event_get_context (event);
 
+	LOG ("show_embed_popup context %x", context)
+
 	if ((context & EMBED_CONTEXT_LINK) &&
 	    (context & EMBED_CONTEXT_IMAGE))
 	{
@@ -1416,13 +1582,11 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	{
 		popup = "/EphyImagePopup";
 	}
-#if MOZILLA_SNAPSHOT > 12
 	else if (context & EMBED_CONTEXT_INPUT)
 	{
 		popup = "/EphyInputPopup";
 		update_edit_actions_sensitivity (window, FALSE);
 	}
-#endif
 	else
 	{
 		popup = framed ? "/EphyFramedDocumentPopup" :
@@ -1480,9 +1644,6 @@ tab_context_menu_cb (EphyEmbed *embed,
 	g_return_val_if_fail (EPHY_IS_TAB (tab), FALSE);
 	g_return_val_if_fail (window->priv->active_tab == tab, FALSE);
 
-	window = ephy_tab_get_window (tab);
-	g_return_val_if_fail (window != NULL, FALSE);
-
 	show_embed_popup (window, tab, event);
 
 	return FALSE;
@@ -1496,7 +1657,7 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 	GtkToggleAction *action;
 
 	g_return_if_fail (EPHY_IS_WINDOW (window));
-	if (ephy_tab_get_window (new_tab) != window) return;
+	g_return_if_fail (gtk_widget_get_toplevel (GTK_WIDGET (new_tab)) == GTK_WIDGET (window));
 
 	old_tab = window->priv->active_tab;
 
@@ -1525,6 +1686,12 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
 						      G_CALLBACK (sync_tab_security),
 						      window);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
+						      G_CALLBACK (sync_tab_popup_windows),
+						      window);
+		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
+						      G_CALLBACK (sync_tab_popups_allowed),
+						      window);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (old_tab),
 						      G_CALLBACK (sync_tab_title),
 						      window);
@@ -1552,6 +1719,8 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 		sync_tab_message	(new_tab, NULL, window);
 		sync_tab_navigation	(new_tab, NULL, window);
 		sync_tab_security	(new_tab, NULL, window);
+		sync_tab_popup_windows	(new_tab, NULL, window);
+		sync_tab_popups_allowed	(new_tab, NULL, window);
 		sync_tab_title		(new_tab, NULL, window);
 		sync_tab_zoom		(new_tab, NULL, window);
 
@@ -1583,6 +1752,14 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 					 "notify::security-level",
 					 G_CALLBACK (sync_tab_security),
 					 window, 0);
+		g_signal_connect_object (G_OBJECT (new_tab),
+					 "notify::hidden-popup-count",
+					 G_CALLBACK (sync_tab_popup_windows),
+					 window, 0);
+		g_signal_connect_object (G_OBJECT (new_tab),
+					 "notify::popups-allowed",
+					 G_CALLBACK (sync_tab_popups_allowed),
+					 window, 0);
 		g_signal_connect_object (G_OBJECT (new_tab),
 					 "notify::title",
 					 G_CALLBACK (sync_tab_title),
@@ -1678,6 +1855,11 @@ tab_detached_cb (EphyNotebook *notebook,
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN))
+	{
+		return;
+	}
+
 	window = ephy_window_new ();
 	ephy_notebook_move_tab (notebook,
 				EPHY_NOTEBOOK (ephy_window_get_notebook (window)),
@@ -1698,7 +1880,12 @@ tab_delete_cb (EphyNotebook *notebook,
 {
 	g_return_val_if_fail (EPHY_IS_TAB (tab), FALSE);
 
-	if (ephy_embed_has_modified_forms (ephy_tab_get_embed (tab)))
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_QUIT) &&
+	    gtk_notebook_get_n_pages (GTK_NOTEBOOK (window->priv->notebook)) == 1)
+	{
+		return TRUE;
+	}
+	else if (ephy_embed_has_modified_forms (ephy_tab_get_embed (tab)))
 	{
 		return !confirm_close_with_modified_forms (window);
 	}
@@ -1800,6 +1987,9 @@ ephy_window_get_property (GObject *object,
 		case PROP_ACTIVE_TAB:
 			g_value_set_object (value, window->priv->active_tab);
 			break;
+		case PROP_CHROME:
+			g_value_set_flags (value, window->priv->chrome);
+			break;
 	}
 }
 
@@ -1819,6 +2009,7 @@ ephy_window_class_init (EphyWindowClass *klass)
 	gtkobject_class->destroy = ephy_window_destroy;
 
 	widget_class->show = ephy_window_show;
+	widget_class->key_press_event = ephy_window_key_press_event;
 
 	g_object_class_install_property (object_class,
 					 PROP_ACTIVE_TAB,
@@ -1917,10 +2108,41 @@ browse_with_caret_notifier (GConfClient *client,
 				      eel_gconf_get_boolean (CONF_BROWSE_WITH_CARET));
 }
 
+static void
+allow_popups_notifier (GConfClient *client,
+		       guint cnxn_id,
+		       GConfEntry *entry,
+		       EphyWindow *window)
+{
+	GList *tabs;
+	EphyTab *tab;
+
+	g_return_if_fail (EPHY_IS_WINDOW (window));
+
+	tabs = ephy_window_get_tabs (window);
+
+	for (; tabs; tabs = g_list_next (tabs))
+	{
+		tab = EPHY_TAB (tabs->data);
+		g_return_if_fail (EPHY_IS_TAB (tab));
+
+		g_object_notify (G_OBJECT (tab), "popups-allowed");
+	}
+}
+
+static void
+action_request_forward_cb (GObject *toolbar,
+			   const char *name,
+                	   GObject *bookmarksbar)
+{
+	g_signal_emit_by_name (bookmarksbar, "action_request", name);
+}
+
 static void
 ephy_window_init (EphyWindow *window)
 {
 	EphyExtension *manager;
+	EphyEmbedSingle *single;
 
 	LOG ("EphyWindow initialising %p", window)
 
@@ -1932,6 +2154,7 @@ ephy_window_init (EphyWindow *window)
 	window->priv->exit_fullscreen_popup = NULL;
 	window->priv->num_tabs = 0;
 	window->priv->has_size = FALSE;
+	window->priv->chrome = EPHY_EMBED_CHROME_ALL;
 	window->priv->should_save_chrome = FALSE;
 	window->priv->mode = EPHY_WINDOW_MODE_NORMAL;
 
@@ -1946,6 +2169,7 @@ ephy_window_init (EphyWindow *window)
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
 			    GTK_WIDGET (window->priv->notebook),
 			    TRUE, TRUE, 0);
+	gtk_widget_show (GTK_WIDGET (window->priv->notebook));
 
 	window->priv->statusbar = ephy_statusbar_new ();
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
@@ -1962,8 +2186,21 @@ ephy_window_init (EphyWindow *window)
 	window->priv->enc_menu = ephy_encoding_menu_new (window);
 	window->priv->bmk_menu = ephy_bookmarks_menu_new (window);
 
-	/* create the toolbar */
+	/* create the toolbars */
 	window->priv->toolbar = toolbar_new (window);
+	window->priv->bookmarksbar = ephy_bookmarksbar_new (window);
+
+	/* forward the toolbar's action_request signal to the bookmarks toolbar,
+	 * so the user can also have bookmarks on the normal toolbar
+	 */
+	g_signal_connect (window->priv->toolbar, "action_request",
+			  G_CALLBACK (action_request_forward_cb),
+			  window->priv->bookmarksbar);
+
+	/* Add the toolbars to the window */
+	gtk_box_pack_end (GTK_BOX (window->priv->menu_dock),
+			  window->priv->bookmarksbar,
+			  FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (window->priv->menu_dock),
 			  GTK_WIDGET (window->priv->toolbar),
 			  FALSE, FALSE, 0);
@@ -1974,9 +2211,14 @@ ephy_window_init (EphyWindow *window)
 	manager = EPHY_EXTENSION (ephy_shell_get_extensions_manager (ephy_shell));
 	ephy_extension_attach_window (manager, window);
 
-	/* show widgets */
-	gtk_widget_show (GTK_WIDGET (window->priv->toolbar));
-	gtk_widget_show (GTK_WIDGET (window->priv->notebook));
+	/* We only set the model now after attaching the extensions, so that
+	 * extensions already have created their actions which may be on
+	 * the toolbar
+	 */
+	egg_editable_toolbar_set_model
+		(EGG_EDITABLE_TOOLBAR (window->priv->toolbar),
+		 EGG_TOOLBARS_MODEL
+			 (ephy_shell_get_toolbars_model (ephy_shell, FALSE)));
 
 	g_signal_connect (window, "window-state-event",
 			  G_CALLBACK (ephy_window_state_event_cb),
@@ -1985,6 +2227,11 @@ ephy_window_init (EphyWindow *window)
 			  G_CALLBACK (ephy_window_delete_event_cb),
 			  window);
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN))
+	{
+		gtk_window_fullscreen (GTK_WINDOW (window));
+	}
+
 	/* lockdown pref notifiers */
 	window->priv->disable_arbitrary_url_notifier_id = eel_gconf_notification_add
 		(CONF_LOCKDOWN_DISABLE_ARBITRARY_URL,
@@ -2024,6 +2271,18 @@ ephy_window_init (EphyWindow *window)
 		(CONF_BROWSE_WITH_CARET,
 		 (GConfClientNotifyFunc)browse_with_caret_notifier, window);
 
+	window->priv->allow_popups_notifier_id = eel_gconf_notification_add
+		(CONF_SECURITY_ALLOW_POPUPS,
+		 (GConfClientNotifyFunc)allow_popups_notifier, window);
+
+	/* network status */
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	network_status_changed (single,
+			        ephy_embed_single_get_offline_mode (single),
+				window);
+	g_signal_connect (single, "network-status",
+			  G_CALLBACK (network_status_changed), window);
+
 	/* ensure the UI is updated */
 	gtk_ui_manager_ensure_update (GTK_UI_MANAGER (window->ui_merge));
 
@@ -2034,6 +2293,11 @@ static void
 ephy_window_finalize (GObject *object)
 {
         EphyWindow *window = EPHY_WINDOW (object);
+	GObject *single;
+
+	single = ephy_embed_shell_get_embed_single (embed_shell);
+	g_signal_handlers_disconnect_by_func
+		(single, G_CALLBACK (network_status_changed), window);
 
 	eel_gconf_notification_remove (window->priv->disable_arbitrary_url_notifier_id);
 	eel_gconf_notification_remove (window->priv->disable_bookmark_editing_notifier_id);
@@ -2044,6 +2308,7 @@ ephy_window_finalize (GObject *object)
 	eel_gconf_notification_remove (window->priv->disable_save_to_disk_notifier_id);
 	eel_gconf_notification_remove (window->priv->disable_command_line_notifier_id);
 	eel_gconf_notification_remove (window->priv->browse_with_caret_notifier_id);
+	eel_gconf_notification_remove (window->priv->allow_popups_notifier_id);
 
 	if (window->priv->find_dialog)
 	{
@@ -2070,12 +2335,28 @@ ephy_window_finalize (GObject *object)
 	g_object_unref (ephy_shell);
 }
 
+/**
+ * ephy_window_new:
+ *
+ * Equivalent to g_object_new() but returns an #EphyWindow so you don't have
+ * to cast it.
+ *
+ * Return value: a new #EphyWindow
+ **/
 EphyWindow *
 ephy_window_new (void)
 {
 	return EPHY_WINDOW (g_object_new (EPHY_TYPE_WINDOW, NULL));
 }
 
+/**
+ * ephy_window_new_with_chrome:
+ * @chrome: an #EphyEmbedChrome
+ *
+ * Identical to ephy_window_new(), but allows you to specify a chrome.
+ *
+ * Return value: a new #EphyWindow
+ **/
 EphyWindow *
 ephy_window_new_with_chrome (EphyEmbedChrome chrome)
 {
@@ -2084,6 +2365,13 @@ ephy_window_new_with_chrome (EphyEmbedChrome chrome)
 					  NULL));
 }
 
+/**
+ * ephy_window_set_print_preview:
+ * @window: an #EphyWindow
+ * @enabled: %TRUE to enable print preview mode
+ *
+ * Sets whether the window is in print preview mode.
+ **/
 void
 ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 {
@@ -2119,6 +2407,14 @@ ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 	}
 }
 
+/**
+ * ephy_window_get_toolbar:
+ * @window: an #EphyWindow
+ *
+ * Returns this window's toolbar as an #EggEditableToolbar.
+ *
+ * Return value: an #EggEditableToolbar
+ **/
 GtkWidget *
 ephy_window_get_toolbar (EphyWindow *window)
 {
@@ -2127,6 +2423,30 @@ ephy_window_get_toolbar (EphyWindow *window)
 	return GTK_WIDGET (window->priv->toolbar);
 }
 
+/**
+ * ephy_window_get_bookmarksbar:
+ * @window: an #EphyWindow
+ *
+ * Returns this window's bookmarks toolbar, which is an #EggEditableToolbar.
+ *
+ * Return value: an #EggEditableToolbar
+ **/
+GtkWidget *
+ephy_window_get_bookmarksbar (EphyWindow *window)
+{
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
+
+	return GTK_WIDGET (window->priv->bookmarksbar);
+}
+
+/**
+ * ephy_window_get_notebook:
+ * @window: an #EphyWindow
+ *
+ * Returns the #GtkNotebook used by this window.
+ *
+ * Return value: the @window's #GtkNotebook
+ **/
 GtkWidget *
 ephy_window_get_notebook (EphyWindow *window)
 {
@@ -2135,6 +2455,14 @@ ephy_window_get_notebook (EphyWindow *window)
 	return GTK_WIDGET (window->priv->notebook);
 }
 
+/**
+ * ephy_window_get_statusbar:
+ * @window: an #EphyWindow
+ *
+ * Returns this window's statusbar as an #EphyStatusbar.
+ *
+ * Return value: This window's statusbar
+ **/
 GtkWidget *
 ephy_window_get_statusbar (EphyWindow *window)
 {
@@ -2143,6 +2471,15 @@ ephy_window_get_statusbar (EphyWindow *window)
 	return GTK_WIDGET (window->priv->statusbar);
 }
 
+/**
+ * ephy_window_add_tab:
+ * @window: an #EphyWindow
+ * @tab: an #EphyTab
+ * @position: the position in @window's #GtkNotebook
+ * @jump_to: %TRUE to switch to @tab's new notebook page after insertion
+ *
+ * Inserts @tab into @window.
+ **/
 void
 ephy_window_add_tab (EphyWindow *window,
 		     EphyTab *tab,
@@ -2156,10 +2493,17 @@ ephy_window_add_tab (EphyWindow *window,
 
 	widget = GTK_WIDGET(ephy_tab_get_embed (tab));
 
-	ephy_notebook_insert_tab (EPHY_NOTEBOOK (window->priv->notebook),
-				  tab, position, jump_to);
+	ephy_notebook_add_tab (EPHY_NOTEBOOK (window->priv->notebook),
+			       tab, position, jump_to);
 }
 
+/**
+ * ephy_window_jump_to_tab:
+ * @window: an #EphyWindow
+ * @tab: an #EphyTab inside @window
+ *
+ * Switches @window's #GtkNotebook to open @tab as its current page.
+ **/
 void
 ephy_window_jump_to_tab (EphyWindow *window,
 			 EphyTab *tab)
@@ -2188,6 +2532,13 @@ real_get_active_tab (EphyWindow *window, int page_num)
 	return EPHY_TAB (tab);
 }
 
+/**
+ * ephy_window_remove_tab:
+ * @window: an #EphyWindow
+ * @tab: an #EphyTab
+ *
+ * Removes @tab from @window.
+ **/
 void
 ephy_window_remove_tab (EphyWindow *window,
 		        EphyTab *tab)
@@ -2217,14 +2568,14 @@ ephy_window_remove_tab (EphyWindow *window,
  * @window: a #EphyWindow
  * @url: the url to load
  *
- * Load a new url in the active tab of the window.
- * Unlike ephy_embed_load_url this function activate
+ * Loads a new url in the active tab of @window.
+ * Unlike ephy_embed_load_url(), this function activates
  * the embed.
  *
  **/
 void
 ephy_window_load_url (EphyWindow *window,
-			const char *url)
+		      const char *url)
 {
 	EphyEmbed *embed;
 
@@ -2237,11 +2588,24 @@ ephy_window_load_url (EphyWindow *window,
 	ephy_embed_activate (embed);
 }
 
-void ephy_window_activate_location (EphyWindow *window)
+/**
+ * ephy_window_activate_location:
+ * @window: an #EphyWindow
+ *
+ * Activates the location entry on @window's toolbar.
+ **/
+void
+ephy_window_activate_location (EphyWindow *window)
 {
 	toolbar_activate_location (window->priv->toolbar);
 }
 
+/**
+ * ephy_window_show:
+ * @widget: an #EphyWindow
+ *
+ * Shows @widget if it is hidden.
+ **/
 void
 ephy_window_show (GtkWidget *widget)
 {
@@ -2268,6 +2632,14 @@ ephy_window_show (GtkWidget *widget)
 	GTK_WIDGET_CLASS (parent_class)->show (widget);
 }
 
+/**
+ * ephy_window_get_active_tab:
+ * @window: an #EphyWindow
+ *
+ * Returns @window's active #EphyTab.
+ *
+ * Return value: @window's active tab
+ **/
 EphyTab *
 ephy_window_get_active_tab (EphyWindow *window)
 {
@@ -2277,6 +2649,15 @@ ephy_window_get_active_tab (EphyWindow *window)
 	return window->priv->active_tab;
 }
 
+/**
+ * ephy_window_get_active_embed:
+ * @window: an #EphyWindow
+ *
+ * Return @window's active #EphyEmbed. This is identical to calling
+ * ephy_window_get_active_tab() followed by ephy_tab_get_embed().
+ *
+ * Return value: @window's active embed
+ **/
 EphyEmbed *
 ephy_window_get_active_embed (EphyWindow *window)
 {
@@ -2296,22 +2677,14 @@ ephy_window_get_active_embed (EphyWindow *window)
  *
  * Returns the list of #EphyTab:s in the window.
  *
+ * Return value: a newly-allocated list of #EphyTab:s
  */
 GList *
 ephy_window_get_tabs (EphyWindow *window)
 {
-	GtkNotebook *notebook;
-	GList *list = NULL;
-	int i, num;
+	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
 
-	notebook = GTK_NOTEBOOK (window->priv->notebook);
-	num = gtk_notebook_get_n_pages (notebook);
-	for (i = 0; i < num; i++)
-	{
-		list = g_list_prepend (list, gtk_notebook_get_nth_page (notebook, i));
-	}
-
-	return g_list_reverse (list);
+	return gtk_container_get_children (GTK_CONTAINER (window->priv->notebook));
 }
 
 static void
@@ -2354,6 +2727,12 @@ ephy_window_notebook_switch_page_cb (GtkNotebook *notebook,
 	update_tabs_menu_sensitivity (window);
 }
 
+/**
+ * ephy_window_find:
+ * @window: an #EphyWindow
+ *
+ * Displays @window's Find dialog.
+ **/
 void
 ephy_window_find (EphyWindow *window)
 {
@@ -2376,6 +2755,14 @@ ephy_window_find (EphyWindow *window)
 	ephy_dialog_show (window->priv->find_dialog);
 }
 
+/**
+ * ephy_window_set_zoom:
+ * @window: an #EphyWindow
+ * @zoom: the desired zoom level
+ *
+ * Sets the zoom on @window's active #EphyEmbed. A @zoom of 1.0 corresponds to
+ * 100% zoom (normal size).
+ **/
 void
 ephy_window_set_zoom (EphyWindow *window,
 		      float zoom)
@@ -2388,7 +2775,7 @@ ephy_window_set_zoom (EphyWindow *window,
 	embed = ephy_window_get_active_embed (window);
         g_return_if_fail (embed != NULL);
 
-	current_zoom = ephy_embed_zoom_get (embed);
+	current_zoom = ephy_embed_get_zoom (embed);
 
 	if (zoom == ZOOM_IN)
 	{
@@ -2401,7 +2788,54 @@ ephy_window_set_zoom (EphyWindow *window,
 
 	if (zoom != current_zoom)
 	{
-		ephy_embed_zoom_set (embed, zoom, TRUE);
+		ephy_embed_set_zoom (embed, zoom);
+	}
+}
+
+void
+ephy_window_load_in_tabs (EphyWindow *window, EphyTab *tab, GList *uri_list)
+{
+	EphyEmbed *embed = NULL;
+	GList *l;
+	guint num = 0;
+	GnomeVFSURI *uri;
+
+	if (tab != NULL)
+	{
+		embed = ephy_tab_get_embed (tab);
+		g_return_if_fail (EPHY_IS_EMBED (embed));
+	}
+
+	l = uri_list;
+	while (l != NULL && num < INSANE_NUMBER_OF_URLS)
+	{
+		gchar *url = NULL;
+
+		uri = (GnomeVFSURI*) l->data;
+		url = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+
+		if (num == 0 && embed != NULL)
+		{
+			/**
+			 * The first url is special: if the drag was to an
+			 * existing tab, load it there
+			 */
+			ephy_embed_load_url (embed, url);
+		}
+		else
+		{
+			tab = ephy_shell_new_tab (ephy_shell, window,
+						  tab, url,
+						  EPHY_NEW_TAB_OPEN_PAGE |
+						  EPHY_NEW_TAB_IN_EXISTING_WINDOW |
+						  (tab ? EPHY_NEW_TAB_APPEND_AFTER :
+							 EPHY_NEW_TAB_APPEND_LAST));
+		}
+
+		g_free (url);
+		url = NULL;
+		l = l->next;
+		++num;
 	}
 }
 
@@ -2458,3 +2892,27 @@ ephy_window_view_bookmarksbar_cb (GtkAction *action,
 	sync_chrome_with_view_toggle (action, window,
 				      EPHY_EMBED_CHROME_BOOKMARKSBAR);
 }
+
+static void
+ephy_window_view_popup_windows_cb (GtkAction *action,
+				   EphyWindow *window)
+{
+	EphyTab *tab;
+	gboolean allow;
+
+	g_return_if_fail (EPHY_IS_WINDOW (window));
+
+	tab = ephy_window_get_active_tab (window);
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
+	{
+		allow = TRUE;
+	}
+	else
+	{
+		allow = FALSE;
+	}
+
+	g_object_set (G_OBJECT (tab), "popups-allowed", allow, NULL);
+}
