@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.82 2004/06/21 19:25:41 marco Exp $
+ *  $Id: prefs-dialog.c,v 1.84 2004/07/31 13:18:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -602,7 +602,7 @@ create_node_combo (EphyDialog *dialog,
 
 	combo = GTK_COMBO_BOX (ephy_dialog_get_control (dialog, properties[prop].id));
 
-	nodemodel = ephy_tree_model_node_new (node, NULL);
+	nodemodel = ephy_tree_model_node_new (node);
 
 	title_col = ephy_tree_model_node_add_prop_column
 			(nodemodel, G_TYPE_STRING, EPHY_NODE_ENCODING_PROP_TITLE_ELIDED);
@@ -1323,6 +1323,8 @@ prefs_download_path_button_clicked_cb (GtkWidget *button,
 					    GTK_WIDGET (parent),
 					    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 					    NULL, EPHY_FILE_FILTER_NONE);
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fc),
+						     g_get_home_dir ());
 
 		g_signal_connect (GTK_DIALOG (fc), "response",
 				    G_CALLBACK (download_path_response_cb),
